@@ -373,19 +373,20 @@ class Eniam():
         for key in lexicon:
             if hasattr(lexicon[key], 'rule'):
                 lexicon[key] = lexicon[key].rule()
-            if '|rule_id|' in lexicon[key]:
-                lexicon[key] = lexicon[key].split('|rule_id|')[1]
 
         lexicon_custom = []
         for key in lexicon:
-            if "__pos__" in key:
+            key_str = key
+            if '|rule_id|' in key_str:
+                key_str = key_str.split('|rule_id|')[1]
+            if "__pos__" in key_str:
                 for pos in SUPPORTED_VALUES:
-                    key_str = ",".join([key.replace("__pos__", ""), f"pos={pos}"])
+                    key_str = ",".join([key_str.replace("__pos__", ""), f"pos={pos}"])
                     lexicon_custom.append(f"{key_str}: {lexicon[key]};")
-            elif key == "__root__":
+            elif key_str == "__root__":
                 lexicon_custom.append(f"lemma=</sentence>,pos=interp:     BRACKET {lexicon[key]};")
             else:
-                lexicon_custom.append(f"{key}: {lexicon[key]};")
+                lexicon_custom.append(f"{key_str}: {lexicon[key]};")
 
         lexicon_custom_keywords_str = " ".join(lexicon_keywords)
         lexicon_custom_str = "\n".join(lexicon_custom)
